==> 5.4.tar.gz: laravel-docs/documentation.md <==
- ## Prologue
    - [Release Notes](/docs/{{version}}/releases)
    - [Upgrade Guide](/docs/{{version}}/upgrade)
    - [Contribution Guide](/docs/{{version}}/contributions)
- ## Getting Started
    - [Installation](/docs/{{version}}/installation)
    - [Configuration](/docs/{{version}}/configuration)
    - [Directory Structure](/docs/{{version}}/structure)
    - [Homestead](/docs/{{version}}/homestead)
    - [Valet](/docs/{{version}}/valet)
- ## Architecture Concepts
    - [Request Lifecycle](/docs/{{version}}/lifecycle)
    - [Service Container](/docs/{{version}}/container)
    - [Service Providers](/docs/{{version}}/providers)
    - [Facades](/docs/{{version}}/facades)
    - [Contracts](/docs/{{version}}/contracts)
- ## The Basics
    - [Routing](/docs/{{version}}/routing)
    - [Middleware](/docs/{{version}}/middleware)
    - [CSRF Protection](/docs/{{version}}/csrf)
    - [Controllers](/docs/{{version}}/controllers)
    - [Requests](/docs/{{version}}/requests)
    - [Responses](/docs/{{version}}/responses)
    - [Views](/docs/{{version}}/views)
    - [Session](/docs/{{version}}/session)
    - [Validation](/docs/{{version}}/validation)
    - [Errors & Logging](/docs/{{version}}/errors)
- ## Frontend
    - [Blade Templates](/docs/{{version}}/blade)
    - [Localization](/docs/{{version}}/localization)
    - [Frontend Scaffolding](/docs/{{version}}/frontend)
    - [Compiling Assets](/docs/{{version}}/mix)
- ## Security
    - [Authentication](/docs/{{version}}/authentication)
    - [API Authentication](/docs/{{version}}/passport)
    - [Authorization](/docs/{{version}}/authorization)
    - [Encryption](/docs/{{version}}/encryption)
    - [Hashing](/docs/{{version}}/hashing)
    - [Password Reset](/docs/{{version}}/passwords)
- ## Digging Deeper
    - [Artisan Console](/docs/{{version}}/artisan)
    - [Broadcasting](/docs/{{version}}/broadcasting)
    - [Cache](/docs/{{version}}/cache)
    - [Collections](/docs/{{version}}/collections)
    - [Events](/docs/{{version}}/events)
    - [File Storage](/docs/{{version}}/filesystem)
    - [Helpers](/docs/{{version}}/helpers)
    - [Mail](/docs/{{version}}/mail)
    - [Notifications](/docs/{{version}}/notifications)
    - [Package Development](/docs/{{version}}/packages)
    - [Queues](/docs/{{version}}/queues)
    - [Task Scheduling](/docs/{{version}}/scheduling)
- ## Database
    - [Getting Started](/docs/{{version}}/database)
    - [Query Builder](/docs/{{version}}/queries)
    - [Pagination](/docs/{{version}}/pagination)
    - [Migrations](/docs/{{version}}/migrations)
    - [Seeding](/docs/{{version}}/seeding)
    - [Redis](/docs/{{version}}/redis)
- ## Eloquent ORM
    - [Getting Started](/docs/{{version}}/eloquent)
    - [Relationships](/docs/{{version}}/eloquent-relationships)
    - [Collections](/docs/{{version}}/eloquent-collections)
    - [Mutators](/docs/{{version}}/eloquent-mutators)
    - [Serialization](/docs/{{version}}/eloquent-serialization)
- ## Testing
    - [Getting Started](/docs/{{version}}/testing)
    - [HTTP Tests](/docs/{{version}}/http-tests)
    - [Browser Tests](/docs/{{version}}/dusk)
    - [Database](/docs/{{version}}/database-testing)
    - [Mocking](/docs/{{version}}/mocking)
- ## Official Packages
    - [Cashier](/docs/{{version}}/billing)
    - [Envoy](/docs/{{version}}/envoy)
    - [Passport](/docs/{{version}}/passport)
    - [Scout](/docs/{{version}}/scout)
    - [Socialite](/docs/{{version}}/socialite)

==> 5.8.tar.gz: laravel-docs/documentation.md <==
- ## Prologue
    - [Release Notes](/docs/{{version}}/releases)
    - [Upgrade Guide](/docs/{{version}}/upgrade)
    - [Contribution Guide](/docs/{{version}}/contributions)
    - [API Documentation](/api/{{version}})
- ## Getting Started
    - [Installation](/docs/{{version}}/installation)
    - [Configuration](/docs/{{version}}/configuration)
    - [Directory Structure](/docs/{{version}}/structure)
    - [Homestead](/docs/{{version}}/homestead)
    - [Valet](/docs/{{version}}/valet)
    - [Deployment](/docs/{{version}}/deployment)
- ## Architecture Concepts
    - [Request Lifecycle](/docs/{{version}}/lifecycle)
    - [Service Container](/docs/{{version}}/container)
    - [Service Providers](/docs/{{version}}/providers)
    - [Facades](/docs/{{version}}/facades)
    - [Contracts](/docs/{{version}}/contracts)
- ## The Basics
    - [Routing](/docs/{{version}}/routing)
    - [Middleware](/docs/{{version}}/middleware)
    - [CSRF Protection](/docs/{{version}}/csrf)
    - [Controllers](/docs/{{version}}/controllers)
    - [Requests](/docs/{{version}}/requests)
    - [Responses](/docs/{{version}}/responses)
    - [Views](/docs/{{version}}/views)
    - [URL Generation](/docs/{{version}}/urls)
    - [Session](/docs/{{version}}/session)
    - [Validation](/docs/{{version}}/validation)
    - [Error Handling](/docs/{{version}}/errors)
    - [Logging](/docs/{{version}}/logging)
- ## Frontend
    - [Blade Templates](/docs/{{version}}/blade)
    - [Localization](/docs/{{version}}/localization)
    - [Frontend Scaffolding](/docs/{{version}}/frontend)
    - [Compiling Assets](/docs/{{version}}/mix)
- ## Security
    - [Authentication](/docs/{{version}}/authentication)
    - [API Authentication](/docs/{{version}}/api-authentication)
    - [Authorization](/docs/{{version}}/authorization)
    - [Email Verification](/docs/{{version}}/verification)
    - [Encryption](/docs/{{version}}/encryption)
    - [Hashing](/docs/{{version}}/hashing)
    - [Password Reset](/docs/{{version}}/passwords)
- ## Digging Deeper
    - [Artisan Console](/docs/{{version}}/artisan)
    - [Broadcasting](/docs/{{version}}/broadcasting)
    - [Cache](/docs/{{version}}/cache)
    - [Collections](/docs/{{version}}/collections)
    - [Events](/docs/{{version}}/events)
    - [File Storage](/docs/{{version}}/filesystem)
    - [Helpers](/docs/{{version}}/helpers)
    - [Mail](/docs/{{version}}/mail)
    - [Notifications](/docs/{{version}}/notifications)
    - [Package Development](/docs/{{version}}/packages)
    - [Queues](/docs/{{version}}/queues)
    - [Task Scheduling](/docs/{{version}}/scheduling)
- ## Database
    - [Getting Started](/docs/{{version}}/database)
    - [Query Builder](/docs/{{version}}/queries)
    - [Pagination](/docs/{{version}}/pagination)
    - [Migrations](/docs/{{version}}/migrations)
    - [Seeding](/docs/{{version}}/seeding)
    - [Redis](/docs/{{version}}/redis)
- ## Eloquent ORM
    - [Getting Started](/docs/{{version}}/eloquent)
    - [Relationships](/docs/{{version}}/eloquent-relationships)
    - [Collections](/docs/{{version}}/eloquent-collections)
    - [Mutators](/docs/{{version}}/eloquent-mutators)
    - [API Resources](/docs/{{version}}/eloquent-resources)
    - [Serialization](/docs/{{version}}/eloquent-serialization)
- ## Testing
    - [Getting Started](/docs/{{version}}/testing)
    - [HTTP Tests](/docs/{{version}}/http-tests)
    - [Console Tests](/docs/{{version}}/console-tests)
    - [Browser Tests](/docs/{{version}}/dusk)
    - [Database](/docs/{{version}}/database-testing)
    - [Mocking](/docs/{{version}}/mocking)
- ## Official Packages
    - [Cashier](/docs/{{version}}/billing)
    - [Dusk](/docs/{{version}}/dusk)
    - [Envoy](/docs/{{version}}/envoy)
    - [Horizon](/docs/{{version}}/horizon)
    - [Passport](/docs/{{version}}/passport)
    - [Scout](/docs/{{version}}/scout)
    - [Socialite](/docs/{{version}}/socialite)
    - [Telescope](/docs/{{version}}/telescope)
